@@ -3,7 +3,7 @@ import os.path as P
 import django
 
 
-target_path = P.join( P.dirname(__file__) , "../fitterlog_server/")
+target_path = P.join( P.dirname(__file__) , "../fitterlog_server_module/")
 flag = target_path in sys.path
 
 if not flag:
